/*
 Teknisa - Tecnologia em Informtica

 Nome: Limpeza de Dados dos sistemas de Compras e Suprimentos

 Criao:
 28/11/2005 - Marcelo Alex. S. Silva
*/

CREATE OR REPLACE PROCEDURE USR_LIMPEZA_CMPSUP_GR(
   P_DTLIMPEZA IN DATE DEFAULT NULL)
AS
   V_ERROR        VARCHAR2(2000);
   V_PASSO        NUMBER := 0;
BEGIN
   EXECUTE IMMEDIATE 'ALTER TRIGGER  GRAVA_LOGSOLICITA DISABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER  GRAVA_MOVOPSOL    DISABLE';
   FOR C_SOLICITA IN
      (SELECT
          rowid,
          SOLICITA.CDFILSOLI,
          SOLICITA.CDFILLANCA,
          SOLICITA.NRSOLICMP
       FROM
          SOLICITA
       WHERE
         (SOLICITA.CDFILSOLI   <>   'X'        ) AND
         (SOLICITA.CDFILLANCA  <>   'X'        ) AND
         (SOLICITA.DTSOLCMP  <=   P_DTLIMPEZA  )
       ORDER BY
          SOLICITA.CDFILSOLI)
   LOOP
      v_passo        := 0;
      DELETE MOVOPSOL
      WHERE
         C_SOLICITA.CDFILSOLI  = MOVOPSOL.CDFILSOLMOV AND
         C_SOLICITA.CDFILLANCA = MOVOPSOL.CDFILLANMOV AND
         C_SOLICITA.NRSOLICMP  = MOVOPSOL.NRSOLIMOV;
      V_PASSO       := 1;
      DELETE SOLICITA
      WHERE  ROWID = C_SOLICITA.ROWID;
   COMMIT;
   END LOOP;

   EXECUTE IMMEDIATE 'ALTER TRIGGER  GRAVA_LOGSOLICITA ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER  GRAVA_MOVOPSOL    ENABLE';

   V_PASSO        := 2;

   DELETE LOGCOLETAPR
   WHERE
      CDFILIALLOG <> 'X' AND
      DTFINVALLOG <= P_DTLIMPEZA;

   DELETE LOGITEMCOLE
   WHERE
      CDFILIALLIC <> 'X' AND
      DTFINVALLIC <= P_DTLIMPEZA;
   COMMIT;


   V_PASSO        := 3;
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGITEMCOLE DISABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGCOLETAPR DISABLE';

   FOR C_COLETAPR IN
      (SELECT
          rowid,
          COLETAPR.CDFILIAL,
          COLETAPR.NRCOLEPRECO
       FROM
          COLETAPR
       WHERE
          (CDFILIAL <> 'X' ) AND
          (DTFINVALCOL <= P_DTLIMPEZA))
   LOOP
      V_PASSO := 4;
      DELETE ITMPREVLIST
      WHERE
         ITMPREVLIST.CDFILIAL    = C_COLETAPR.CDFILIAL AND
         ITMPREVLIST.NRCOLEPRECO = C_COLETAPR.NRCOLEPRECO;

      COMMIT;
      V_PASSO := 5;
      FOR ITCOLE IN
         (SELECT
             rowid,
             CDFILIAL,
             NRCOLEPRECO,
             CDFORNECED,
             CDPRODUTO
          FROM
             ITEMCOLE
          WHERE
             ITEMCOLE.CDFILIAL = C_COLETAPR.CDFILIAL AND
             ITEMCOLE.NRCOLEPRECO = C_COLETAPR.NRCOLEPRECO)
      LOOP
         DELETE ITEMCOLE WHERE ROWID = ITCOLE.ROWID;
         COMMIT;
      END LOOP;

      V_PASSO := 6;

      UPDATE PARTFILI
         SET CDFILCOTA = NULL,
             NRCOLEPRECO = NULL
      WHERE
         PARTFILI.CDFILCOTA = C_COLETAPR.CDFILIAL AND
         PARTFILI.NRCOLEPRECO = C_COLETAPR.NRCOLEPRECO;
      UPDATE PARAMPRODSUP
         SET CDFILCOLETA = NULL,
             NRCOLEPRECO = NULL
      WHERE
         PARAMPRODSUP.CDFILCOLETA = C_COLETAPR.CDFILIAL AND
         PARAMPRODSUP.NRCOLEPRECO = C_COLETAPR.NRCOLEPRECO;
      DELETE COLETAPR
      WHERE ROWID = C_COLETAPR.ROWID;
      COMMIT;
   END LOOP;

   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGITEMCOLE ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGCOLETAPR ENABLE';
   V_PASSO        := 7;
   DELETE PREVLISTA
   WHERE
      NOT EXISTS(SELECT
                    '1'
                 FROM
                    ITEMCOLE
                 WHERE
                    ITEMCOLE.NRSEQPRELIST = PREVLISTA.NRSEQPRELIST AND
                    ITEMCOLE.CDFILIAL     = PREVLISTA.CDFILIAL);
   COMMIT;


   EXECUTE IMMEDIATE 'ALTER TRIGGER ATUALIZA_PEDIDO                DISABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIS_ITEMPRODUTO            DISABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGAUTOFORNE             DISABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGITEMAUTF              DISABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER NF_BAIXA_AF                    DISABLE';

   DELETE LOGAUTOFORNE
   WHERE
      CDFILDESLAF <> 'X' AND
      CDFILLANLAF <> 'X' AND
      NRAUTFORLAF <> 'X' AND
      DTOPERALAF <= P_DTLIMPEZA;

   DELETE LOGITEMAUTF
   WHERE
      CDFIDESLITAF <> 'X' AND
      CDFILANLITAF <> 'X' AND
      NRAUTOFLITAF <> 'X' AND
      CDMARCALITAF <> 'X' AND
      CDPRODLITAF  <> 'X' AND
      DTPROGLITAF  <= P_DTLIMPEZA;
   COMMIT;

   FOR C_AUTOFORNE IN
      (SELECT
          rowid,
          AUTOFORNE.CDFILDEST,
          AUTOFORNE.CDFILLANC,
          AUTOFORNE.NRAUTOFORN
       FROM
          AUTOFORNE
       WHERE
        (CDFILDEST         <> 'X') AND
        (CDFILLANC         <> 'X') AND
        (NRAUTOFORN        <> 'X') AND
        (DTAUTOFORN <= P_DTLIMPEZA))
   LOOP
      UPDATE ITEMPRODUTO
      SET
        ITEMPRODUTO.CDFILDEST   = NULL,
        ITEMPRODUTO.NRAUTOFORN  = NULL,
        ITEMPRODUTO.CDMARCA     = NULL,
        ITEMPRODUTO.DTPROGENTAF = NULL
      WHERE
        ITEMPRODUTO.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
        ITEMPRODUTO.CDFILIAL    = C_AUTOFORNE.CDFILLANC  AND
        ITEMPRODUTO.NRAUTOFORN  = C_AUTOFORNE.NRAUTOFORN;
      V_PASSO        := 8;

      DELETE NFRELACAF
      WHERE
        NFRELACAF.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
        NFRELACAF.CDFILLANC   = C_AUTOFORNE.CDFILLANC  AND
        NFRELACAF.NRAUTOFORN  = C_AUTOFORNE.NRAUTOFORN;
      V_PASSO        := 9;

      DELETE NFRELACAFSAI
      WHERE
        NFRELACAFSAI.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
        NFRELACAFSAI.CDFILLANC   = C_AUTOFORNE.CDFILLANC  AND
        NFRELACAFSAI.NRAUTOFORN  = C_AUTOFORNE.NRAUTOFORN;
      V_PASSO        := 10;

      DELETE ITEMSAIDOL
      WHERE
        ITEMSAIDOL.CDFILDEST   = C_AUTOFORNE.CDFILDEST  AND
        ITEMSAIDOL.CDFILLANC   = C_AUTOFORNE.CDFILLANC  AND
        ITEMSAIDOL.NRAUTOFORN  = C_AUTOFORNE.NRAUTOFORN;
      V_PASSO        := 11;

      UPDATE AUTOFORNE
         SET CDFILDESTCON = NULL,
             CDFILLANCCON = NULL,
             NRAUTOFORCON = NULL
      WHERE
         CDFILDESTCON = C_AUTOFORNE.CDFILDEST AND
         CDFILLANCCON = C_AUTOFORNE.CDFILLANC AND
         NRAUTOFORCON = C_AUTOFORNE.NRAUTOFORN;
      V_PASSO        := 12;

      DELETE AUTOFORNE
      WHERE ROWID   = C_AUTOFORNE.ROWID;
      COMMIT;
   END LOOP;
   V_PASSO        := 13;
   DELETE FROM CALECOMP
   WHERE
      CDFILIAL   <> 'X' AND
      CDPERIENTR <> 'X' AND
      DTENTREGA  <= P_DTLIMPEZA;
   COMMIT;
   V_PASSO        := 14;
   DELETE FROM FERICOMP
   WHERE
      CDFILIAL   <> 'X' AND
      DTFERICOMP <= P_DTLIMPEZA;
   COMMIT;
   V_PASSO        := 15;
   DELETE FROM APURPRECO
   WHERE
      CDFILCENTCMP <> 'X' AND
      NRAPURPREC   <> 'X' AND
      DTFINAPUPREC <= P_DTLIMPEZA;
   DELETE FROM ITMAPURPREC
   WHERE
      CDCENTITMAP <> 'X'         AND
      NRSEQITMAP  <> 'X'         AND
      CDREGITMAP  <> 'X'         AND
      CDFORNITMAP <> 'X'         AND
      NRCOLEITMAP <> 'X'         AND
      DTENTRAPUT  <= P_DTLIMPEZA AND
      CDFILIAP    <> 'X'         AND
      CDPRODITMAP <> 'X'         AND
      CDMARCITMAP <> 'X';
   COMMIT;
   V_PASSO        := 16;
   EXECUTE IMMEDIATE 'ALTER TRIGGER ATUALIZA_PEDIDO                ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIS_ITEMPRODUTO            ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGAUTOFORNE             ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGITEMAUTF              ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER NF_BAIXA_AF                    ENABLE';
   FOR C_CS IN (SELECT CDFILIAL, DTCUSTOSUP
                FROM CUSTOSUP
                WHERE  CDFILIAL  <> 'X'  AND
                       CDPRODUTO <> 'X'  AND                
                       DTCUSTOSUP <= P_DTLIMPEZA
                GROUP BY CDFILIAL,DTCUSTOSUP ) LOOP
      V_PASSO        := 17;
      UPDATE CUSTOSUP
         SET CDFILIALORIG = NULL,
             CDPRODORIG   = NULL,
             DTCUSTSUPORI = NULL
      WHERE
         CDFILIALORIG = C_CS.CDFILIAL   AND
         CDPRODORIG   = C_CS.DTCUSTOSUP;
      DELETE CUSTOSUP
      WHERE  CDFILIAL    = C_CS.CDFILIAL   AND
             DTCUSTOSUP  = C_CS.DTCUSTOSUP;
      COMMIT;
   END LOOP;
   COMMIT;
EXCEPTION
WHEN OTHERS THEN
   V_ERROR :=  SQLERRM(SQLCODE);
   EXECUTE IMMEDIATE 'ALTER TRIGGER  GRAVA_LOGSOLICITA   ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER  GRAVA_MOVOPSOL      ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER ATUALIZA_PEDIDO      ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER LOG_FIS_ITEMPRODUTO  ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGAUTOFORNE   ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGITEMAUTF    ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER NF_BAIXA_AF          ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGITEMCOLE    ENABLE';
   EXECUTE IMMEDIATE 'ALTER TRIGGER GRAVA_LOGCOLETAPR    ENABLE';
   RAISE_APPLICATION_ERROR (-20101, 'PASSO : '||V_PASSO||'   -   '||V_ERROR);
END;
/

